import { Exception } from "./Exception";
export interface LogEvent {
    id: string;
    date: Date;
    result: "OK" | "WARN" | "ERROR";
    context: {
        [key: string]: string;
    };
    info: {
        [key: string]: string;
    };
    elapsedTime: number;
    action?: string;
    errorCode?: string;
}
export declare class EventLogger {
    private environmentContext;
    private uuidCounter;
    private logQueue;
    setContext(context: {
        [key: string]: string | (() => string);
    }): void;
    /**
     * Logger can log simple event (string type + parameter), or an exception
     * Declare function overload signatures in advance
     * Ref: http://www.typescriptlang.org/docs/handbook/functions.html#overloads
     */
    log(action: string, info?: {
        [key: string]: string;
    }): () => void;
    log(exception: Exception): () => void;
    collect(): Array<Readonly<LogEvent>>;
    empty(): void;
    private appendLog;
    private getUUID;
}
