import { SagaIterator } from "redux-saga";
import { ActionHandler, LifecycleDecoratorFlag, TickIntervalDecoratorFlag } from "./module";
import { ModuleLifecycleListener } from "./platform/Module";
import { State } from "./reducer";
/**
 * For latest decorator spec, please ref following:
 *      https://tc39.github.io/proposal-decorators/#sec-decorator-functions-element-descriptor
 *      https://github.com/tc39/proposal-decorators/blob/master/METAPROGRAMMING.md
 */
/**
 * Decorator type declaration, required by TypeScript
 */
declare type HandlerDecorator = (target: object, propertyKey: string, descriptor: TypedPropertyDescriptor<ActionHandler>) => TypedPropertyDescriptor<ActionHandler>;
declare type LifecycleHandlerDecorator = (target: object, propertyKey: keyof ModuleLifecycleListener, descriptor: TypedPropertyDescriptor<ActionHandler & LifecycleDecoratorFlag>) => TypedPropertyDescriptor<ActionHandler>;
declare type OnTickHandlerDecorator = (target: object, propertyKey: "onTick", descriptor: TypedPropertyDescriptor<ActionHandler & TickIntervalDecoratorFlag>) => TypedPropertyDescriptor<ActionHandler>;
declare type VoidFunctionDecorator = (target: object, propertyKey: string, descriptor: TypedPropertyDescriptor<(...args: any[]) => void>) => TypedPropertyDescriptor<(...args: any[]) => void>;
declare type AnyFunctionDecorator = (target: object, propertyKey: string, descriptor: TypedPropertyDescriptor<(...args: any[]) => any>) => TypedPropertyDescriptor<(...args: any[]) => any>;
declare type HandlerInterceptor<S> = (handler: ActionHandler, rootState: Readonly<S>) => SagaIterator;
declare type FunctionInterceptor<S> = (handler: () => void, rootState: Readonly<S>) => void;
/**
 * Used for ActionHandler functions
 */
export declare function createActionHandlerDecorator<S extends State = State>(interceptor: HandlerInterceptor<S>): HandlerDecorator;
/**
 * Used for regular functions
 */
export declare function createRegularDecorator<S extends State = State>(interceptor: FunctionInterceptor<S>): VoidFunctionDecorator;
/**
 * Built-in ActionHandler decorators
 */
export declare function Loading(identifier?: string): HandlerDecorator;
export declare function Log(): HandlerDecorator;
export declare function Lifecycle(): LifecycleHandlerDecorator;
export declare function Interval(second: number): OnTickHandlerDecorator;
/**
 * Built-in regular function decorators
 */
export declare function Throttle(millisecond: number): VoidFunctionDecorator;
export declare function Memo(memoKeyGenerator?: (args: any[]) => string): AnyFunctionDecorator;
export {};
