import React from "react";
import { AppRegistry } from "react-native";
import { Provider } from "react-redux";
import { app } from "../app";
import { errorAction } from "../reducer";
import { ErrorBoundary } from "../util/ErrorBoundary";
export function startApp(config) {
    renderApp(config.registeredAppName, config.componentType, config.beforeRendering);
    setupGlobalErrorHandler(config.errorHandlerModule);
    if (config.maskedEventKeywords) {
        app.maskedEventKeywords = config.maskedEventKeywords;
    }
}
function renderApp(registeredAppName, EntryComponent, beforeRendering) {
    class WrappedAppComponent extends React.PureComponent {
        constructor(props) {
            super(props);
            this.state = { initialized: false };
        }
        async componentDidMount() {
            if (beforeRendering) {
                await beforeRendering();
            }
            this.setState({ initialized: true });
        }
        render() {
            return (this.state.initialized && (<Provider store={app.store}>
                        <ErrorBoundary>
                            <EntryComponent />
                        </ErrorBoundary>
                    </Provider>));
        }
    }
    AppRegistry.registerComponent(registeredAppName, () => WrappedAppComponent);
}
function setupGlobalErrorHandler(ErrorHandlerModule) {
    ErrorUtils.setGlobalHandler((error, isFatal) => {
        if (isFatal) {
            console.info("***** Fatal Error *****");
        }
        app.store.dispatch(errorAction(error));
    });
    const errorHandler = new ErrorHandlerModule("error-handler", {});
    app.errorHandler = errorHandler.onError.bind(errorHandler);
}
//# sourceMappingURL=bootstrap.js.map